==> open-xchange-sessionstorage-hazelcast_7.2.2.orig.tar.bz2: open-xchange-sessionstorage-hazelcast-7.2.2/com.openexchange.sessionstorage.hazelcast/src/com/openexchange/sessionstorage/hazelcast/AltIdPredicate.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.sessionstorage.hazelcast;

import com.hazelcast.core.MapEntry;
import com.hazelcast.query.Predicate;
import com.openexchange.session.Session;

/**
 * {@link AltIdPredicate}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public class AltIdPredicate implements Predicate<String, HazelcastStoredSession> {

    private static final long serialVersionUID = -3741029445819911943L;

    private String altId;

    /**
     * Initializes a new {@link AltIdPredicate}.
     *
     * @param altId The alternative ID to match
     */
    public AltIdPredicate(String altId) {
        super();
        this.altId = altId;
    }

    /**
     * Initializes a new {@link AltIdPredicate}.
     */
    public AltIdPredicate() {
        super();
    }

    @Override
    public boolean apply(MapEntry<String, HazelcastStoredSession> mapEntry) {
        return null != mapEntry && null != mapEntry.getValue() && null != altId &&
            altId.equals(mapEntry.getValue().getParameter(Session.PARAM_ALTERNATIVE_ID));
    }

}

==> open-xchange-sessionstorage-hazelcast_7.6.1.orig.tar.bz2: open-xchange-sessionstorage-hazelcast-7.6.1/com.openexchange.sessionstorage.hazelcast/src/com/openexchange/sessionstorage/hazelcast/AltIdPredicate.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.sessionstorage.hazelcast;

import java.util.Map.Entry;
import com.hazelcast.query.Predicate;
import com.openexchange.session.Session;
import com.openexchange.sessionstorage.hazelcast.portable.PortableSession;

/**
 * {@link AltIdPredicate}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public class AltIdPredicate implements Predicate<String, PortableSession> {

    private static final long serialVersionUID = -3741029445819911943L;

    private String altId;

    /**
     * Initializes a new {@link AltIdPredicate}.
     *
     * @param altId The alternative ID to match
     */
    public AltIdPredicate(String altId) {
        super();
        this.altId = altId;
    }

    /**
     * Initializes a new {@link AltIdPredicate}.
     */
    public AltIdPredicate() {
        super();
    }

    @Override
    public boolean apply(Entry<String, PortableSession> mapEntry) {
        return null != mapEntry && null != mapEntry.getValue() && null != altId &&
            altId.equals(mapEntry.getValue().getParameter(Session.PARAM_ALTERNATIVE_ID));
    }

}
